.. _examples:

########
Examples
########

Here are few examples on how to use aeolus

.. note::

   These examples provide practical ways to illustrate the usage of the software, and do not necessarily represent the best scientific methods for any particular type of study.

.. toctree::
   :maxdepth: 1

   00_Constants.ipynb
   01_Loading_Data.ipynb
   02_Model_Field_Names.ipynb
